import { useState } from "react";
import { Credentials } from "../Types";
import { createUser as createUserAPI } from "../Api";
import useAuth from "../useAuth";

export const useCreateUser = () => {
    const [isLoading, setIsLoading] = useState(false);
    const [error, setError] = useState<string | null>(null);
    const { login } = useAuth();

    const createUser = async (credentials: Credentials): Promise<void> => {
        try {
            setIsLoading(true);
            setError(null);

            const createResponse = await createUserAPI(credentials);

            if (createResponse.id) {
                login(credentials);
            } else {
                setError(createResponse.message);
            }
        } catch (error) {
            setError(error as string);
        } finally {
            setIsLoading(false);
        }
    };

    return { createUser, isLoading, error };
};
